@@ -255,7 +255,7 @@ class BflbJLinkPort(object):
                      reset_revert=True,
                      cutoff_time=0,
                      shake_hand_retry=2,
-                     iap_timeout=0,
+                     isp_timeout=0,
                      boot_load=False):
         self.if_write(bytearray(1))
         success, ack = self.if_read(2)
